==> qgvdial_0.2.656.orig.tar.gz: qgvdial-0.2.656.orig/src/GVInbox.h <==
/*
qgvdial is a cross platform Google Voice Dialer
Copyright (C) 2010  Yuvraaj Kelkar

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Contact: yuvraaj@gmail.com
*/

#ifndef __GVINBOX_H__
#define __GVINBOX_H__

#include "global.h"

// For some reason the symbian MOC doesn't like it if I don't include QObject
// even though it is present in QtCore which is included in global.h
#include <QObject>

class InboxModel;

class GVInbox : public QObject
{
    Q_OBJECT

public:
    GVInbox (QObject *parent = 0);
    ~GVInbox(void);

    void deinitModel ();
    void initModel ();

signals:
    //! Status emitter for status bar
    void status(const QString &strText, int timeout = 2000);

    //! Emitted on user request to call a known contact
    void callNumber (const QString &strNumber,
                     const QString &strNameLink = QString ());

    //! Emitted on user request to send an SMS to an unknown number
    void textANumber (const QString &strNumber,
                      const QString &strNameLink = QString ());

    //! Emitted when we identify a voicemail link
    void retrieveVoicemail (const QString &strVmailLink);

    //! Emitted when the Inbox AbstractModel is created
    void setInboxModel(QAbstractItemModel *model);

    //! Emitted when the Inbox selector is to be set
    void setInboxSelector(const QString &strSelector);

public slots:
    //! Invoked when the user requests a refresh
    void refresh ();
    //! Invoked when the user requests a full inbox refresh
    void refreshFullInbox ();

    void onInboxSelected (const QString &strSelection);

    void loginSuccess ();
    void loggedOut ();

private slots:
    void oneInboxEntry (const GVInboxEntry &hevent);
    void getInboxDone (bool bOk, const QVariantList &arrParams);

private:
    void prepView ();

private:
    //! Mutex for the following variables
    QMutex          mutex;

    //! The currently selected messages: all, voicemail, etc
    QString         strSelectedMessages;

    //! Are we logged in?
    bool            bLoggedIn;

    //! The inbox model
    InboxModel     *modelInbox;
};

#endif //__GVINBOX_H__

==> qgvdial_0.2.697.orig.tar.gz: qgvdial-0.2.697.orig/src/GVInbox.h <==
/*
qgvdial is a cross platform Google Voice Dialer
Copyright (C) 2010  Yuvraaj Kelkar

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Contact: yuvraaj@gmail.com
*/

#ifndef __GVINBOX_H__
#define __GVINBOX_H__

#include "global.h"

// For some reason the symbian MOC doesn't like it if I don't include QObject
// even though it is present in QtCore which is included in global.h
#include <QObject>

class InboxModel;

class GVInbox : public QObject
{
    Q_OBJECT

public:
    GVInbox (QObject *parent = 0);
    ~GVInbox(void);

    void deinitModel ();
    void initModel ();

signals:
    //! Status emitter for status bar
    void status(const QString &strText, int timeout = 2000);

    //! Emitted on user request to call a known contact
    void callNumber (const QString &strNumber,
                     const QString &strNameLink = QString ());

    //! Emitted on user request to send an SMS to an unknown number
    void textANumber (const QString &strNumber,
                      const QString &strNameLink = QString ());

    //! Emitted when we identify a voicemail link
    void retrieveVoicemail (const QString &strVmailLink);

    //! Emitted when the Inbox AbstractModel is created
    void setInboxModel(QAbstractItemModel *model);

    //! Emitted when the Inbox selector is to be set
    void setInboxSelector(const QString &strSelector);

public slots:
    //! Invoked when the user requests a refresh
    void refresh ();
    //! Invoked when the user requests a full inbox refresh
    void refreshFullInbox ();

    void onInboxSelected (const QString &strSelection);

    void loginSuccess ();
    void loggedOut ();

    void onSigMarkAsRead(const QString &msgId);

private slots:
    void oneInboxEntry (const GVInboxEntry &hevent);
    void getInboxDone (bool bOk, const QVariantList &arrParams);
    void onInboxEntryMarked (bool bOk, const QVariantList &params);

private:
    void prepView ();

private:
    //! Mutex for the following variables
    QMutex          mutex;

    //! The currently selected messages: all, voicemail, etc
    QString         strSelectedMessages;

    //! Are we logged in?
    bool            bLoggedIn;

    //! The inbox model
    InboxModel     *modelInbox;
};

#endif //__GVINBOX_H__
